
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

module PublisherController
  extend ActiveSupport::Concern
  include Paginator

  included do
    before_action :authenticate, only: [:show_all_drafts, :show_liked_learning_objects, :show_submissions, :show_liked_collections]
    before_action :set_publisher, only: [:show_all_drafts, :show_all_learning_objects, :show_submissions, :show_all_collections, :show_liked_learning_objects, :show_liked_collections]
    before_action -> { authorize @publisher }, only: [:show_all_drafts, :show_submissions, :show_liked_learning_objects, :show_liked_collections]
  end

  def show_all_drafts
    learning_objects = paginate LearningObject.where(publisher: @publisher, state: LearningObject.states[:draft])
    render json: learning_objects
  end

  # GET /v1/users/1/learning_objects
  def show_all_learning_objects
    learning_objects = paginate LearningObject.where(publisher: @publisher, state: LearningObject.states[:published])
    render json: learning_objects
  end

  # GET /v1/users/:id/submissions
  def show_submissions
    status = params[:status]
    if !status.nil? && !Submission.statuses.has_key?(status) && status != 'all'
      render json: {"error": "Status not found."}, status: :unprocessable_entity
    else
      if current_user.is_curator?
        submissions = current_user.assignments
      else
        submissions = current_user.submissions
      end
      submissions = submissions.where(status: status) unless status.nil? || status == 'all'
      render json: paginate(submissions), status: :ok
    end
  end

  def show_all_collections
    collections = paginate ::UserPolicy::Scope.new(current_user, @publisher, Collection).resolve.where(owner: @publisher)
    render json: collections
  end

  def show_liked_learning_objects
    includes = [:taggings, :tags, :subject_relations, :subjects, :stage_relations, :educational_stages, :publisher, :language, :license]
    learning_objects = paginate LearningObject.includes(includes).where(id: Like.where(user: @publisher, likeable_type: 'LearningObject').pluck(:likeable_id)
    )
    render json: learning_objects
  end

  def show_liked_collections
    collections = paginate Collection.where( id: Like.where(user: @publisher, likeable_type: 'Collection').pluck(:likeable_id)
    )
    render json: collections
  end

  protected

  def authenticate
    authenticate_user!
  end

  def set_publisher
    user, id = request.path.split('/')[2, 2]
    return nil unless %w(users institutions).include? user
    publisher_model = user.singularize.classify.constantize
    @publisher = publisher_model.find(id)
  end
end
