
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

class V1::ComplaintsController < ApplicationController
  include ::DeletedObjectsController
  include ::Paginator

  before_action :authenticate_user!, only: [:create]

  # GET v1/complaints
  # GET v1/complaints.json
  def index
    complaints = paginate Complaint
    render json: complaints
  end

  # POST v1/complaints
  # POST v1/complaints.json
  def create
    @complaint = Complaint.new(complaint_params)

    if @complaint.save
      ComplaintsMailer.new_complaint_received(@complaint, @current_user).deliver_now
      render json: @complaint, status: :created
    else
      render json: @complaint.errors, status: :unprocessable_entity
    end
  end

  private

  def deleted_resource
    Complaint
  end

  def complaint_params
    params.require(:complaint).permit(:user_id, :description,:complainable_id, :complaint_reason_id, :complainable_type)
  end

end
