
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

module Scoreable
  extend ActiveSupport::Concern

  def normalized_review_average
    average_by_max(review_ratings_average, 5.0)
  end

  def normalized_thumbnail
    thumbnail? ? 1 : 0
  end

  def normalized_description
    description? ? 1 : 0
  end

  def normalized_views
    average_by_max(views.count, self.class.maximum(:views_count))
  end

  def normalized_likes
    average_by_max(likes.count, self.class.maximum(:likes_count))
  end

  def normalized_downloads
    average_by_max(downloads.count, self.class.maximum(:downloads_count))
  end

  def normalized_shares
    average_by_max(shares.count, self.class.maximum(:shares_count))
  end

  def normalized_bookmarked
    max = Bookmark.where(bookmarkable_type: self.class.name).group(:bookmarkable_id).order('count_all DESC').count
    return 0.0 if max.blank?

    value = Bookmark.where(bookmarkable_id: id, bookmarkable_type: self.class.name).count
    average_by_max(value, max.first[1])
  end

  private

  def average_by_max(value, max)
    return 0.0 if max <= 0.0
    value.to_f / max.to_f
  end
end
