
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

module Subjectable
  extend ActiveSupport::Concern

  included do
    has_many :subjects, through: :subject_relations, dependent: :destroy
    has_many :subject_relations, as: :subjectable, dependent: :destroy
  end

  # A subjectable can add subjects
  # Examples:
  # subjectable.add_subjects(ids: [1, 2, 3])
  # subjectable.add_subjects(ids: [1])
  def add_subjects(ids: [])
    ids.each do |subject_id|
      subject = Subject.find(subject_id)
      SubjectRelation.where(subject: subject, subjectable: self).first_or_create
    end
  end

  # A subjectable can remove subjects
  # Examples:
  # subjectable.remove_subjects(ids: [1, 2, 3])
  def remove_subjects(ids: [])
    ids.each do |subject_id|
      subject = Subject.find(subject_id)
      SubjectRelation.where(subject: subject, subjectable: self).destroy_all
    end
  end

  def update_subjects(ids: [])
    subjectable = self
    old_ids = subjectable.subjects.map { |su| su.id }
    add_subjects(ids: ids - old_ids)
    remove_subjects(ids: old_ids - ids)
  end
end
