
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

class Search < ApplicationRecord
  attr_accessor :page, :results_per_page, :order, :tags, :and_fields

  belongs_to :user
  has_and_belongs_to_many :tags
  has_and_belongs_to_many :subjects
  has_and_belongs_to_many :educational_stages
  has_and_belongs_to_many :object_types
  has_and_belongs_to_many :language
  validates_presence_of :query, :results_per_page, :order, :search_class
  validates_numericality_of :results_per_page, greater_than: 0
  validates :search_class, inclusion: { in: ::SearchService::SEARCH_CLASSES }
  alias_attribute :subjects, :subject_ids
  alias_attribute :educational_stages, :educational_stage_ids
  alias_attribute :object_types, :object_type_ids
  alias_attribute :languages, :language_ids

  def initialize(params = {})
    super(params.merge(defaults(params)))
  end

  def learning_object?
    search_class == 'LearningObject'
  end

  def collection?
    search_class == 'Collection'
  end

  def user?
    search_class == 'User'
  end

  private

  def defaults(params)
    {
      query: '*',
      order: 'score',
      page: 0,
      results_per_page: 10,
      and_fields: []
    }.select { |key, _value| !params.key?(key) }
  end
end
