
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

class ApplicationPolicy
  attr_reader :user, :record

  def initialize(user, record)
    @user = user
    @record = record
  end

  def index?
    false
  end

  def show?
    scope.where(id: record.id).exists?
  end

  def create?
    false
  end

  def new?
    create?
  end

  def update?
    false
  end

  def edit?
    update?
  end

  def destroy?
    false
  end

  def scope
    Pundit.policy_scope!(user, record.class)
  end

  def owns?
    return false if user.nil?
    return true if user_can_edit?

    # return owner.users.include?(user) if owner.is_a?(Institution)

    owner == user
  end

  def user_exists?
    !user.nil?
  end

  def owner
    raise 'You must implement this method!'
  end

  def user_can_create?
    (user_exists? && user.is_submitter?) || (user_exists? && user.is_publisher?)
  end

  def user_can_edit?
    user.is_admin? || user.is_editor?
  end

  def user_can_update?
    (owns? && user.is_publisher?) || (owns? && user.is_submitter?) || (owns? && user.is_partner?) || user.is_admin?
  end

  def user_can_publish?
    (user_can_curate? && record.submitted?) || (owns? && user.is_publisher?)
  end

  def user_can_curate?
    user.is_curator?
  end

  class Scope < ApplicationPolicy
    attr_reader :user, :scope

    def initialize(user, scope)
      @user = user
      @scope = scope
    end

    def resolve
      scope
    end
  end
end
