
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

class UserPolicy < ApplicationPolicy
  include FollowablePolicy
  include PublisherPolicy

  class Scope < PublisherPolicy::Scope; end

	def update?
    record if same_user? || authorized_user?
	end

  def create?
    authorized_user?
  end

  def show?
    record if user_exists?
  end

  def destroy?
    record if same_user? || user.is_admin?
  end

  def own_reviews?
    record if same_user? || user_can_edit?
  end

  def received_reviews?
    record if same_user? || user_can_edit?
  end

  def teacher_requests?
    record if user.is_supervisor?
  end

  def add_teacher?
    record if user.is_supervisor?
  end

  def remove_teacher?
    record if same_user? || user.is_supervisor?
  end

  def authorized_user?
    return false if ( record.is_admin? && !user.is_admin? )
    if ( record.is_editor? )
      if !( same_user? || user.is_admin? )
        return false
      end
    end
    user_can_edit?
  end

  def same_user?
    record == user
  end
end
