
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

class Dspace::LearningObjectImporter

  def initialize(items, publisher)
    @items = items
    @publisher = publisher
  end

  def import
    items = []

    @items.each do |item|
      next if item_exists? item
      learning_object = LearningObjectBuilder.build_from_dspace(item, @publisher)
      next if learning_object.blank?
      create_attachments(learning_object, item.bit_streams)
      items << learning_object
      yield(learning_object) if block_given?
    end

    LearningObject.import items, recursive: true unless items.empty?
  end

  private

  def create_attachments(learning_object, bitstreams)
    bitstreams = JSON.parse bitstreams if bitstreams.class == String
    bitstreams.each do |bitstream|
      learning_object.attachments.new ::Dspace::AttachmentMapper.call(bitstream)
      ThumbnailGenerateWorker.perform_async(learning_object.attachments.last)
    end
  end

  def item_exists?(item)
    LearningObject.where(id_dspace: item.id).exists?
  end

end
