
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

require 'dspace'

class LearningObjectPublisher
  def initialize(dspace_client)
    @dspace = dspace_client
  end

  # create a learning object with draft status
  def create_draft(draft, publisher)
    item = create_dspace_item(draft)
    # save on postgres
    draft.id_dspace = item.id
    draft.publisher = publisher
    draft.save

    update_dspace(draft)

    draft
  end

  # post *media_path* to *learning_object* on dspace
  def upload(learning_object, media_path)
    attachment = learning_object.attachments.create(name: File.basename(media_path))
    DspaceUploadWorker.perform_async(learning_object.id, media_path, attachment.id, learning_object.description)
    attachment
  end

  ## publish *learning_object*
  # this method will create thumbnails, change state to published and will save it.
  def publish(learning_object)
    return true if learning_object.published?

    learning_object.state = LearningObject.states[:published]
    learning_object.published_at = Time.current
    if learning_object.link?
      att = LearningObject::Attachment.new
      ThumbnailGenerateWorker.perform_async(att.id, learning_object.link)
    end
    # ThumbnailGenerateWorker.perform_async learning_object.id, learning_object.link if learning_object.link?
    learning_object.save
  end

  def update_dspace(object)
    metadata = []
    dspace_metadata_mapper(object).each do |key, value|
      next if value.blank?
      value = [value] unless value.is_a? Array
      value.each do |v|
        metadata << { 'key' => key, 'value' => v, 'language' => object.language.try(:code) || 'pt' } unless v.blank?
      end
    end
    @dspace.items.update_metadata(metadata, id: object.id_dspace) unless metadata.empty?
  end

  private

  def create_dspace_item(draft)
    @dspace.collections.create_item(build_dspace_item(draft), id: DspaceService::TEST_COLLECTION)
  end

  def build_dspace_item(draft)
    ::Dspace::Item.new('name' => draft.name)
  end

  def dspace_metadata_mapper(object)
    {
      'dc.title' => object.name,
      'dc.object.url' => object.link,
      'dc.contributor.author' => object.author,
      'dc.description' => object.description,
      'dc.language' => object.language.try(:code),
      'dc.type' => object.object_type.try(:name),
      'dc.rights.license' => object.license.try(:name),
      # 'dc.subject.category' => object.subjects,
      'dc.date.submitted' => object.created_at.to_s,
      'dc.curator' => object.curator
    }
  end
end
