
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

module PackageService
  class Generator

    attr_reader :objects

    def initialize(objects)
      @objects = objects.is_a?(Array) ? objects : [objects]
      @filename = nil

      raise 'Invalid objects for PackageService' unless valid?
    end

    def generate
      PackageWorker.perform_async(objects_map, filename)
    end

    def filename
      while @filename.nil? do
        name = "#{SecureRandom.hex(12)}.zip"
        @filename = name unless File.exist?(PackageService.file_root(name))
      end
      @filename
    end

    private

    def valid?
      allowed_classes = PackageService.allowed_classes

      @objects.each do |object|
        return false unless allowed_classes.include? object.class.name
      end

      true
    end

    def objects_map
      @objects.map { |o| { class: o.class, id: o.id } }
    end
  end
end
