
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

require_dependency 'dspace'
require 'mimemagic'

class DspaceUploadWorker
  include Sidekiq::Worker

  @@dspace = nil

  def perform(learning_object_id, media_path, attachment_id = nil, description = nil)
    # find learning object
    learning_object = LearningObject.find learning_object_id

    return false if learning_object.blank?

    # Require dspace gem
    Bundler.require(*Rails.groups)

    # create attachment
    file = File.new(media_path, 'r')
    mime_type = MimeMagic.by_magic(file).type
    bitstream = dspace.items.add_bitstream(file, id: learning_object.id_dspace, name: File.basename(media_path), description: description)
    bitstream.mime_type = mime_type
    attachment = create_attachment(learning_object, bitstream, attachment_id)

    ThumbnailGenerateWorker.perform_async attachment.id, media_path
  end

  private

  def create_attachment(learning_object, bitstream, attachment_id = nil)
    unless attachment_id.nil?
      attachment = learning_object.attachments.find(attachment_id)
      unless attachment.nil?
        attachment.update(map_bitstream2attachment(bitstream))
        return attachment
      end
    end
    learning_object.attachments.create map_bitstream2attachment(bitstream)
  end

  def publisher
    @publisher ||= LearningObjectPublisher.new(dspace)
  end

  def map_bitstream2attachment(bitstream, options = {})
    ::Dspace::AttachmentMapper.call bitstream, options
  end

  def dspace
    @@dspace ||= DspaceService.create_client
  end
end
