
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

require 'acceptance_helpers'
require 'shared/contexts'

resource 'Bookmarks' do
  header 'Accept', 'application/json'
  header 'Content-Type', 'application/json'

  explanation "Bookmark is a relation between user and object called ‘Favoritos’, 
                which are educational contents or collections. Bookmarks do not have an index for itens."

  before { 12.times { create(:learning_object) } }

  let(:bookmarks) { Bookmark.all }
  let(:learning_objects) { LearningObject.all }

  get '/v1/users/:user_id/bookmarks' do
    include_context "authenticate_user"

    parameter :user_id, 'The user id'

    let(:user_id) { @user.id }

    before do
      create(:bookmark, user: @user)
    end

    example_request 'Getting bookmarks' do
      expect(status).to eq(200)
    end
  end

  post 'v1/users/:user_id/bookmarks' do
    include_context "authenticate_user"

    parameter :user_id, 'The user id'
    parameter :id, 'The id of the object', scope: :bookmarks
    parameter :type, 'Represents the type of bookmark, [ LearningObject, Collection]', scope: :bookmarks

    let(:user_id) { @user.id }
    let(:id) { learning_objects.first.id }
    let(:type) { 'LearningObject' }
    let(:raw_post) { params.to_json }

    example_request 'Adding a bookmark' do
      expect(status).to eq(201)
    end
  end

  delete 'v1/users/:user_id/bookmarks/:bookmark_id' do
    include_context "authenticate_user"

    parameter :user_id, 'The user id'
    parameter :bookmark_id, 'The id of the bookmark'
    parameter :id, 'The id of the object', scope: :bookmarks
    parameter :type, 'Represents the type of bookmark, [ LearningObject, Collection]', scope: :bookmarks

    let(:user_id) { @user.id }
    let(:bookmark_id) { @bookmark.id }
    let(:id) { learning_objects.first.id }
    let(:type) { 'LearningObject' }
    let(:raw_post) { params.to_json }

    before do
      @bookmark = create(:bookmark, user: @user, bookmarkable: learning_objects.first )
    end

    example_request 'Removing a bookmark' do
      expect(status).to eq(200)
    end
  end

end
