
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

require 'acceptance_helpers'

resource 'Educational Stages' do
  header 'Accept', 'application/json'
  header 'Content-Type', 'application/json'

  explanation "Educational stages to digital resources, like Ensino Médio, Ensino Fundamental."

  before { 12.times { create(:educational_stage); create(:learning_object) } }

  let(:educationalstages) { EducationalStage.all }
  let(:learning_objects) { LearningObject.all }

  get '/v1/educational_stages' do

    example_request 'Get a list of educational stages' do
      # active model serializer may render model associations in different order for collections (array of items), so we're verifing only returned ids
      expect(status).to eq(200)
    end
  end

  post '/v1/:type/:id/educational_stages' do
    include_context "authenticate_user"

    parameter :id, 'The id of object'
    parameter :type, 'Represents the type of object, [learning_objects, collection]'

    parameter :educational_stages, 'array with the educational_stages ids'

    let(:type) { 'learning_objects' }
    let(:id) { @learning_object.id }
    let(:educational_stages) { [educationalstages.first.id] }
    let(:raw_post) { params.to_json }

    before do
      @learning_object = create(:learning_object, publisher: @user)
    end

    example_request 'Adding Educational Stages' do
      expect(status).to eq(201)
    end
  end

  delete '/v1/:type/:id/educational_stages' do
    include_context "authenticate_user_admin"

    parameter :id, 'The id of object'
    parameter :type, 'Represents the type of object, [learning_objects, collection]'
    parameter :educational_stages, 'array with the educational_stages ids'

    let(:type) { 'learning_objects' }
    let(:id) {@learning_object.id}
    let(:educational_stages) { [educationalstages.first.id] }
    let(:raw_post) { params.to_json }

    before do
      @learning_object = create(:learning_object, publisher: @user)
      create(:stage_relation, stageable: @learning_object, educational_stage: educationalstages.first)
    end

    example_request 'Removing Educational Stages' do
      #do_request
      expect(status).to eq(200)
    end
  end
end
