
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

require 'acceptance_helpers'

resource 'Searches' do

  explanation "Search is a query for Learning Objects, Collections or Users."

  before { 12.times { create(:learning_object); LearningObject.reindex } }

  get '/v1/search' do

    parameter :page, 'Results page number. Starts from 0.'
    parameter :results_per_page, 'Number of results per page'
    parameter :order, 'How the results should be ordered. Default is by score, possible values are: author, publicationasc, publicationdesc, title, likes, downloads, review_average, _score. Users can be sorted by name and _score.'
    parameter :query, 'The query string to be searched. \'*\' returns all the results.'
    parameter :search_class, 'What class of objects are going to be searched. Accepted values: LearningObject, Collection, User'
    parameter :tags, 'Filter the search by tags, separated by ’&’. Example: tags[]=Biologia&tags[]=Artes'
    parameter :subjects, 'Filter the search by subjects. Receives an array of Subject ids. Example: subjects[]=1&subjects[]=2'
    parameter :educational_stages, 'Filter the search by educational_stages. Receives an array of EducationalStage ids. Example: educational_stages[]=1&educational_stages[]=2'
    parameter :types, 'Filter the search by the Learning Object types. Receives an array of ObjectType ids. Example: object_types[]=1&object_types[]=2'


    let(:page) { 0 }
    let(:results_per_page) { 12 }
    let(:order) { "_score" }
    let(:query) { "*" }
    let(:search_class) { "LearningObject" }

    before do
    end


    example_request 'Fetching objects' do
      # active model serializer may render model associations in different order for collections (array of items), so we're verifing only returned ids
      do_request
      expect(status).to eq(200)
      expect(JSON.parse(response_body).map { |o| o['id'] }.sort).to eq(LearningObject.limit(results_per_page).pluck(:id).sort)
    end
  end

  get '/v1/search/autocomplete' do

    parameter :query, 'The query string to be searched'
    parameter :search_class, 'What kind of object are going to be searched'


    let(:search_class) { "LearningObject" }

    example 'Autocomplete objects names' do
      do_request
      expect(status).to eq(200)
    end
  end




end
