
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

require 'acceptance_helpers'
require 'shared/contexts'

resource 'Submissions' do

  explanation "Submissions are requests to publish Learning Objects, which must be accepted by a curator."

  before { 5.times { create(:submission) } }
  before { 1.times { create(:question) } }

  # let(:submissions) { Submission.all }
  # let(:object_types) { ObjectType.all }
  # let(:languages) { Language.all }
  # let(:licenses) { License.all }
  # let(:subject) { Subject.all }
  # let(:educational_stage) { EducationalStage.all }
  let(:questions) { Question.all }


  get '/v1/submissions' do
    include_context "authenticate_user_curator"

    example_request 'Get a list of submissions' do
      expect(JSON.parse(response_body).map { |o| o['id'] }.sort).to eq(Submission.pluck(:id).sort)
      expect(status).to eq(200)
    end
  end

  get '/v1/submissions/:id' do
    include_context "authenticate_user_curator"

    let(:id) { @submission.id }

    before do
      @submission = create(:submission)
    end

    example_request 'Show a submission' do
      expect(JSON.parse(response_body)['id']).to eq(@submission.id)
      expect(status).to eq(200)
    end
  end

  post '/v1/submissions' do
    header "Content-Type", "application/json"
    include_context "authenticate_user_submitter"

    parameter :learning_object_id, 'ID of the Learning Object to be submitted. Must be a draft owned by the signed in user.', scope: :submission

    before do
      @lo = create(:learning_object, publisher: @user)
      @lo.draft!
    end

    let(:learning_object_id) { @lo.id }
    let(:raw_post) { params.to_json }

    example 'Create a submission' do
      do_request
      expect(status).to eq(201)
    end
  end

  post '/v1/submissions/:id/answer' do
    include_context "authenticate_user_curator"

    parameter :justification, 'Text explaining the given answers.', scope: :submission
    parameter :answers, 'Array with each question ID and its answer (true or false).', scope: :submission

    let(:justification) { "justification" }
    let(:answers) { [{question_id: questions.first.id, accepted: true}] }
    let(:raw_post) { params.to_json }
    let(:id) { @submission.id }

    before do
      submitter = create(:user, roles: [Role.find_by(name: 'submitter')])
      lo = create(:learning_object, publisher: submitter)
      @submission = create(:submission, learning_object: lo, submitter: submitter)
    end

    example 'Answer a submission' do
      do_request
      expect(status).to eq(200)
    end
  end

  delete '/v1/submissions/:id' do
    include_context "authenticate_user_submitter"

    let(:id) { @submission.id }

    before do
      lo = create(:learning_object, publisher: @user)
      @submission = create(:submission, learning_object: lo, submitter: @user)
    end

    example 'Destroying a submission' do
      do_request
      expect(status).to eq(200)
    end
  end
end
