
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

require 'test_helper'

class TagTest < ActiveSupport::TestCase
  should have_many :taggings
  should validate_presence_of :name

  test 'an user can tag a learning object' do
    john = users(:john)
    lo = learning_objects(:one)
    assert john.tag(lo, with: ['Tag'])

    # check lo_one tags
    assert_count 2, lo.tags
    assert_count 2, john.taggings
  end

  test 'an user can untag a learning object' do
    john = users(:john)
    lo = learning_objects(:one)
    assert john.untag(lo, 'Tag')

    # check lo_one tags
    assert_count 1, lo.tags
    assert_count 1, john.taggings
  end

  test 'an user can tag a collection' do
    john = users(:john)
    collection = collections(:ufpr)
    assert john.tag(collection, with: ['Tag'])

    # check ufpr tags
    assert_count 3, collection.tags
    assert_count 2, john.taggings
  end

  test 'an user can untag a collection' do
    john = users(:john)
    collection = collections(:ufpr)
    assert john.untag(collection, 'Tag')

    # check ufpr tags
    assert_count 2, collection.tags
    assert_count 1, john.taggings
  end


end
