
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

require 'test_helper'

class SearchServiceTest < ActiveSupport::TestCase
  test 'fetch learning object with all search params' do
    reindex LearningObject

    search = SearchService.search(Search.new(los_complete_search), users(:john))
    search.each {|o| assert_instance_of LearningObject, o}
  end

  test 'fetch all public collections' do
    reindex Collection

    search = SearchService.search(Search.new(collections_search), users(:john))
    search.each {|o| assert_instance_of Collection, o}
  end

  test 'fetch users named john' do
    reindex User

    search = SearchService.search(Search.new(users_john_search), users(:john))
    assert_equal [users(:john), users(:one)], search
  end

  test 'autocomplete users named john' do
    reindex User

    search = SearchService.autocomplete(Search.new(users_john), users(:john))
    assert_equal users_autocomplete_hashes([users(:john), users(:one)]), search
  end

  private

  def los_complete_search
    default_params.merge(
      query: 'teste',
      search_class: 'LearningObject',
      tags: 'Matemática',
      types: 'Imagem'
    )
  end

  def collections_search
    default_params.merge(search_class: 'Collection')
  end

  def users_john_search
    default_params.merge(users_john)
  end

  def users_john
    {
      query: 'John',
      search_class: 'User'
    }
  end

  def default_params
    {
      page: 1,
      results_per_page: 10,
      order: 'score'
    }
  end

  def reindex(klass)
    klass.reindex
    klass.searchkick_index.refresh
  end

  def users_autocomplete_hashes(users = [])
    users.map do |user|
      {
        id: user.id,
        name: user.name,
        type: 'User',
        thumbnail: user.avatar.url(:thumb)
      }
    end
  end
end
